@@ -1,17 +1,16 @@
-# -*- coding: utf-8 -*-
 """
     pygments.styles.fruity
     ~~~~~~~~~~~~~~~~~~~~~~
 
-    pygments version of my "native" vim theme.
+    pygments version of my "fruity" vim theme.
 
-    :copyright: 2007 by Armin Ronacher.
-    :license: BSD, see LICENSE for more details.
+    :copyright: Copyright 2006-2022 by the Pygments team, see AUTHORS.
+    :license: BSD, see LICENSE for details.
 """
 
 from pygments.style import Style
 from pygments.token import Token, Comment, Name, Keyword, \
-    Generic, Number, String
+    Generic, Number, String, Whitespace
 
 class FruityStyle(Style):
     """
@@ -19,8 +18,10 @@ class FruityStyle(Style):
     """
 
     background_color = '#111111'
+    highlight_color = '#333333'
 
     styles = {
+        Whitespace:         '#888888',
         Token:              '#ffffff',
         Generic.Output:     '#444444 bg:#222222',
         Keyword:            '#fb660a bold',
@@ -28,7 +29,6 @@ class FruityStyle(Style):
         Number:             '#0086f7 bold',
         Name.Tag:           '#fb660a bold',
         Name.Variable:      '#fb660a',
-        Name.Constant:      '#fb660a',
         Comment:            '#008800 bg:#0f140f italic',
         Name.Attribute:     '#ff0086 bold',
         String:             '#0086d2',
